;; Generated package description from multishell.el  -*- no-byte-compile: t -*-
(define-package "multishell" "1.1.10.0.20220605.120254" "Organize use of multiple shell buffers, local and remote" '((cl-lib "0.5")) :commit "d08d9549222e5ba75013f1c32af24b6dda22190d" :authors '(("Ken Manheimer" . "ken.manheimer@gmail.com")) :maintainer '("Ken Manheimer" . "ken.manheimer@gmail.com") :keywords '("processes") :url "https://github.com/kenmanheimer/EmacsMultishell")
